# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
require 'puppet_x/enterprisemodules/weblogic/provider'

Puppet::Type.type(:wls_opatch).provide(:prefetching) do
  include EasyType::Provider

  desc 'Apply Oracle OPatches'

  mk_resource_methods

  def self.prefetch(resources)
    os_user = check_single_os_user(resources)
    orainst_dir = check_single_orainst_dir(resources)

    all_patches = oracle_homes(resources).collect { |h| patches_in_home(h, os_user, orainst_dir) }.flatten
    resources.each_key do |patch_name|
      resources[patch_name].provider = new(:name => name, :ensure => :present) if all_patches.include?(patch_name)
    end
  end

  def opatch(command, _options = {})
    oracle_product_home_dir = resource[:oracle_product_home_dir]
    jre_specified = resource[:jdk_home_dir] ? " -jre #{resource[:jdk_home_dir]} " : ''
    orainst                 = "-invPtrLoc #{resource[:orainst_dir]}/oraInst.loc "
    os_user                 = resource[:os_user]
    full_command            = "#{oracle_product_home_dir}/OPatch/opatch #{command} -oh #{oracle_product_home_dir} #{jre_specified} #{orainst}"
    output = Puppet::Util::Execution.execute(full_command, :failonfail => true, :uid => os_user)
    Puppet.debug output
    output
  end

  private

  def installed_patches
    opatch('lsinventory').scan(/Patch\s.(\d+)\s.*:\sapplied on/).flatten
  end

  def self.patches_in_home(oracle_product_home_dir, os_user, orainst_dir)
    full_command = "#{oracle_product_home_dir}/OPatch/opatch lsinventory -oh #{oracle_product_home_dir} -invPtrLoc #{orainst_dir}/oraInst.loc"
    raw_list = Puppet::Util::Execution.execute(full_command, :failonfail => true, :uid => os_user)
    Puppet.debug raw_list
    patch_ids = raw_list.scan(/Patch\s.(\d+)\s.*:\sapplied on/).flatten
    patch_ids.collect { |p| "#{oracle_product_home_dir}:#{p}" }
  end

  def self.check_single_os_user(resources)
    os_users = resources.map { |_k, v| v.os_user }.uniq
    fail "wls_opatch doesn't support multiple os_users" if os_users.size > 1

    os_users.first
  end

  def self.check_single_orainst_dir(resources)
    orainst_dir = resources.map { |_k, v| v.orainst_dir }.uniq
    fail "wls_opatch doesn't support multiple orainst_dir" if orainst_dir.size > 1

    orainst_dir.first
  end

  def self.oracle_homes(resources)
    resources.map { |_k, v| v.oracle_product_home_dir }.uniq
  end
end
