# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:jta_max_resource_unavailable_millis, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  Maximum duration time, in milliseconds, that a resource is declared dead. After the duration, the resource is declared available again, even if the resource provider does not explicitly re-register the resource.

  An example on how to use this:

      wls_cluster {a_wls_cluster :
         ...
         jta_max_resource_unavailable_millis => 'a_value'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_cluster:jta_max_resource_unavailable_millis']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type('Optional[String]')

  maps_to('JTACluster/%<cluster_name>s/MaxResourceUnavailableMillis')
end
