# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:multicast_data_encryption, :parent => Puppet::Parameter::WlsProperty) do
  include Puppet_X::EnterpriseModules::WebLogic::Types::NumberedBoolean

  desc <<-DESC
  Enables multicast data to be encrypted. Only the multicast data is encrypted. Multicast header information is not encrypted.

  An example on how to use this:

      wls_cluster {a_wls_cluster :
         ...
         multicast_data_encryption => 1,
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_cluster:multicast_data_encryption']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type("Optional[Variant[Enum['absent'],Integer[0,1]]]")

  maps_to('MulticastDataEncryption')
end
