# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:multicast_send_delay, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  The amount of time (between 0 and 250 milliseconds) to delay sending message fragments over multicast in order to avoid OS-level buffer overflow.  Defines the number of milliseconds to delay sending message fragments over multicast in order to avoid OS-level buffer overflow.

  An example on how to use this:

      wls_cluster {a_wls_cluster :
         ...
         multicast_send_delay => '3'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_cluster:multicast_send_delay']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type("Optional[Variant[Enum['absent'],Integer[0,250]]]")
  maps_to('MulticastSendDelay')
end
