# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:txn_affinity_enabled, :parent => Puppet::Parameter::WlsProperty) do
  include Puppet_X::EnterpriseModules::WebLogic::Types::NumberedBoolean

  desc <<-DESC
  If enabled, a server's transaction requests go to servers in the cluster that are already participating in the global transaction.

  An example on how to use this:

      wls_cluster {a_wls_cluster :
         ...
         txn_affinity_enabled => 1,
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_cluster:txn_affinity_enabled']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type("Optional[Variant[Enum['absent'],Integer[0,1]]]")

  maps_to('TxnAffinityEnabled')
end
