# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:multicastaddress, :parent => Puppet::Parameter::WlsProperty) do
  include EasyType::Validators::IPFQDN

  desc <<-DESC
  The multicast address used by cluster members to communicate with each other.  The valid range is from from 224.0.0.0 to 239.255.255.255. The default value used by WebLogic Server is 239.192.0.0.  You should avoid using multicast addresses in the range x.0.0.1  This address should be unique to this cluster and should not be shared by other applications.

  You can use an ip address like this:

      wls_cluster { 'aCluster':
        ...
        multicastaddress => '10.10.10.30',
        ...
      }

  or use a host name like this:

      wls_coherence_cluster { 'aCluster':
        ...
        multicastaddress => 'myhost.exaqmple.com',
        ...
      }

  DESC

  data_type('Optional[String]')

  maps_to('MulticastAddress')
end
