# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:deployment_order, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  An integer value that indicates when this unit is deployed, relative to other deployable units on a server, during startup.  Units with lower values are deployed before those with higher values.

  An example on how to use this:

      wls_coherence_cluster {a_wls_coherence_cluster :
         ...
         deployment_order => '100'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_coherence_cluster:deployment_order']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC
  include EasyType::Types::Integer
  data_type("Optional[Variant[Enum['absent'],Integer]]")

  maps_to('DeploymentOrder')
end
