# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:security_framework_enabled, :parent => Puppet::Parameter::WlsProperty) do
  include Puppet_X::EnterpriseModules::WebLogic::Types::NumberedBoolean

  desc <<-DESC
  Check if security framework is enabled

  An example on how to use this:

      wls_coherence_cluster {a_wls_coherence_cluster :
         ...
         security_framework_enabled => 1,
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_coherence_cluster:security_framework_enabled']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type("Optional[Variant[Enum['absent'],Integer[0,1]]]")

  maps_to('CoherenceClusterResource/%<coherence_cluster_name>s/CoherenceClusterParams/%<coherence_cluster_name>s/SecurityFrameworkEnabled')
end
