# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:unicast_listen_port, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  The port for the cluster unicast listener. A value of 0 indicates that the unicast listener port value will be derived from the server listen port. This value or the derived value will be used only if the CoherenceMemberConfigMBean unicast listen port is 0.

  An example on how to use this:

      wls_coherence_cluster {a_wls_coherence_cluster :
         ...
         unicast_listen_port => 'a_value'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_coherence_cluster:unicast_listen_port']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC
  include EasyType::Types::Integer
  data_type("Optional[Variant[Enum['absent'],Integer[0,9999]]]")

  maps_to('CoherenceClusterResource/%<coherence_cluster_name>s/CoherenceClusterParams/%<coherence_cluster_name>s/UnicastListenPort')
end
