# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:driver_url, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  The URL of the database to connect to. The format of the URL varies by JDBC driver.  The URL is passed to the JDBC driver to create the physical database connections.

  An example on how to use this:

      wls_datasource {a_wls_datasource :
         ...
         driver_url => 'a_value'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_datasource:driver_url']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type('Optional[String]')

  maps_to('JDBCResource/%<datasource_name>s/JDBCDriverParams/%<datasource_name>s/Url')
end
