# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:ds_data_source_list, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  The list of data sources to which the multi data source will route connection requests. The order of data sources in the list determines the failover order.

  An example on how to use this:

      wls_datasource {a_wls_datasource :
         ...
         ds_data_source_list => 'a_value'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_datasource:ds_data_source_list']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type('Optional[String]')

  maps_to('JDBCResource/%<datasource_name>s/JDBCDataSourceParams/%<datasource_name>s/DataSourceList')
end
