# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:ds_proxy_switching_callback, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  The name of the switching callback class for a Proxy data source. This class implements the <code>weblogic.jdbc.extensions.DataSourceSwitchingCallback</code> interface.

  An example on how to use this:

      wls_datasource {a_wls_datasource :
         ...
         ds_proxy_switching_callback => 'a_value'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_datasource:ds_proxy_switching_callback']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type('Optional[String]')

  maps_to('JDBCResource/%<datasource_name>s/JDBCDataSourceParams/%<datasource_name>s/ProxySwitchingCallback')
end
