# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:oracle_proxy_session, :parent => Puppet::Parameter::WlsProperty) do
  include Puppet_X::EnterpriseModules::WebLogic::Types::NumberedBoolean

  desc <<-DESC
  Enables Oracle JDBC Proxy Authentication.  <ul> <li>Only applicable for the Oracle driver.</li> <li>Requires WebLogic Server user IDs are mapped to database user IDs using credential mapping.</li> </ul>

  An example on how to use this:

      wls_datasource {a_wls_datasource :
         ...
         oracle_proxy_session => 1,
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_datasource:oracle_proxy_session']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type("Optional[Variant[Enum['absent'],Integer[0,1]]]")

  maps_to('JDBCResource/%<datasource_name>s/JDBCOracleParams/%<datasource_name>s/OracleProxySession')
end
