# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:pool_inactive_connection_timeout_seconds, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  The number of inactive seconds on a reserved connection before WebLogic Server reclaims the connection and releases it back into the connection pool.  You can use the Inactive Connection Timeout feature to reclaim leaked connections - connections that were not explicitly closed by the application. Note that this feature is not intended to be used in place of properly closing connections.  When set to <code>0</code>, the feature is disabled.

  An example on how to use this:

      wls_datasource {a_wls_datasource :
         ...
         pool_inactive_connection_timeout_seconds => 'a_value'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_datasource:pool_inactive_connection_timeout_seconds']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC
  include EasyType::Types::Integer
  data_type("Optional[Variant[Enum['absent'],Integer]]")

  maps_to('JDBCResource/%<datasource_name>s/JDBCConnectionPoolParams/%<datasource_name>s/InactiveConnectionTimeoutSeconds')
end
