# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:pool_max_capacity, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  The maximum number of physical connections that this connection pool can contain.

  An example on how to use this:

      wls_datasource {a_wls_datasource :
         ...
         pool_max_capacity => '15'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_datasource:pool_max_capacity']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC
  include EasyType::Types::Integer
  data_type("Optional[Variant[Enum['absent'],Integer]]")

  maps_to('JDBCResource/%<datasource_name>s/JDBCConnectionPoolParams/%<datasource_name>s/MaxCapacity')
end
