# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:pool_profile_connection_leak_timeout_seconds, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  The number of seconds that a JDBC connection needs to be held by an application before triggering a connection leak diagnostic profiling record.  When set to <code>0</code>, the timeout is disabled.  This attribute only applies when the connection leak diagnostic profiling option is enabled.

  An example on how to use this:

      wls_datasource {a_wls_datasource :
         ...
         pool_profile_connection_leak_timeout_seconds => 'a_value'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_datasource:pool_profile_connection_leak_timeout_seconds']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC
  include EasyType::Types::Integer
  data_type("Optional[Variant[Enum['absent'],Integer]]")

  maps_to('JDBCResource/%<datasource_name>s/JDBCConnectionPoolParams/%<datasource_name>s/ProfileConnectionLeakTimeoutSeconds')
end
