# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:xa_resource_health_monitoring, :parent => Puppet::Parameter::WlsProperty) do
  include Puppet_X::EnterpriseModules::WebLogic::Types::NumberedBoolean

  desc <<-DESC
  Enables JTA resource health monitoring for an XA data source.  When enabled, if an XA resource fails to respond to an XA call within the period specified in MaxXACallMillis, WebLogic Server  marks the data source as unhealthy and blocks any further calls to the resource.   This property applies to XA data sources only, and is ignored for data sources that use a non-XA driver.

  An example on how to use this:

      wls_datasource {a_wls_datasource :
         ...
         xa_resource_health_monitoring => 1,
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_datasource:xa_resource_health_monitoring']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type("Optional[Variant[Enum['absent'],Integer[0,1]]]")

  maps_to('JDBCResource/%<datasource_name>s/JDBCXAParams/%<datasource_name>s/ResourceHealthMonitoring')
end
