# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:xa_retry_duration_seconds, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  Determines the duration in seconds for which the transaction manager will perform recover operations on the resource.  A value of zero indicates that no retries will be performed.

  An example on how to use this:

      wls_datasource {a_wls_datasource :
         ...
         xa_retry_duration_seconds => 'a_value'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_datasource:xa_retry_duration_seconds']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC
  include EasyType::Types::Integer
  data_type("Optional[Variant[Enum['absent'],Integer]]")

  maps_to('JDBCResource/%<datasource_name>s/JDBCXAParams/%<datasource_name>s/XaRetryDurationSeconds')
end
