# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:jmx_platform_mbean_server_enabled, :parent => Puppet::Parameter::WlsProperty) do
  extend  Puppet_X::EnterpriseModules::WebLogic::DomainPaths # Changes the actual path for domain resource
  include Puppet_X::EnterpriseModules::WebLogic::Types::NumberedBoolean

  desc <<-DESC
  Specifies whether each server instance initializes the JDK's platform MBean server. Enabling it, along with <code>isPlatformMBeanServerUsed</code>, causes WebLogic Server to use the platform MBean server as its Runtime MBean Server.  As of JDK 1.5, JVMs provide a platform MBean server that local processes can instantiate. There can be only one instance of the platform MBean server for each JVM. When a process instantiates this MBean server, the JVM creates several platform MXBeans that provide monitoring data for the JVM itself.  If you set this attribute to <code>true</code>, each WebLogic Server instance invokes the method <code>java.lang.management.ManagementFactory.getPlatformMBeanServer()</code> and thus causes the initialization of the JVM's MXBeans.

  An example on how to use this:

      wls_domain {a_wls_domain :
         ...
         jmx_platform_mbean_server_enabled => 1,
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_domain:jmx_platform_mbean_server_enabled']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type("Optional[Variant[Enum['absent'],Integer[0,1]]]")

  maps_to('JMX/%<domain_name>s/PlatformMBeanServerEnabled')
end
