# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:jta_determiner_candidate_resource_info_list, :parent => Puppet::Parameter::WlsProperty) do
  extend Puppet_X::EnterpriseModules::WebLogic::DomainPaths # Changes the actual path for domain resource

  desc <<-DESC
  Returns a list of one or more transaction resources (determiners). A determiner's in-doubt transaction records are used during transaction recovery when a TLog is not present.

  An example on how to use this:

      wls_domain {a_wls_domain :
         ...
         jta_determiner_candidate_resource_info_list => 'a_value'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_domain:jta_determiner_candidate_resource_info_list']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type('Optional[String]')

  maps_to('JTA/%<domain_name>s/DeterminerCandidateResourceInfoList')
end
