# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:jta_max_resource_requests_on_server, :parent => Puppet::Parameter::WlsProperty) do
  extend Puppet_X::EnterpriseModules::WebLogic::DomainPaths # Changes the actual path for domain resource

  desc <<-DESC
  Maximum number of concurrent requests to resources allowed for each server.

  An example on how to use this:

      wls_domain {a_wls_domain :
         ...
         jta_max_resource_requests_on_server => '50'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_domain:jta_max_resource_requests_on_server']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC
  include EasyType::Types::Integer
  data_type("Optional[Variant[Enum['absent'],Integer]]")

  maps_to('JTA/%<domain_name>s/MaxResourceRequestsOnServer')
end
