# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:log_monitoring_throttle_threshold, :parent => Puppet::Parameter::WlsProperty) do
  extend Puppet_X::EnterpriseModules::WebLogic::DomainPaths # Changes the actual path for domain resource

  desc <<-DESC
  The threshold number of messages logged during the evaluation period which enables or disables the throttling.

  An example on how to use this:

      wls_domain {a_wls_domain :
         ...
         log_monitoring_throttle_threshold => '1500'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_domain:log_monitoring_throttle_threshold']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC
  include EasyType::Types::Integer
  data_type("Optional[Variant[Enum['absent'],Integer]]")

  maps_to('Log/%<domain_name>s/LogMonitoringThrottleThreshold')
end
