# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:dynamic_cluster_size, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  Get the current size of the dynamic cluster (the number of dynamic server instances allowed to be created). The specified number of server instances are dynamically added to the configuration at runtime and associated ServerLifeCycleRuntimeMBeans are created.

  An example on how to use this:

      wls_dynamic_cluster {a_wls_dynamic_cluster :
         ...
         dynamic_cluster_size => 'a_value'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_dynamic_cluster:dynamic_cluster_size']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC
  include EasyType::Types::Integer
  data_type("Optional[Variant[Enum['absent'],Integer]]")

  maps_to('DynamicClusterSize')
end
