# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:min_window_buffer_size, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  The minimum amount of data, in bytes and rounded down to the nearest power of 2, mapped into the JVM's address space per primary store file. Applies to synchronous write policies <code>Direct-Write-With-Cache</code> and <code>Disabled</code>, but only when a native <code>wlfileio</code> library is loaded. See <a href='#getMaxWindowBufferSize'>Maximum Window Buffer Size.</a>

  An example on how to use this:

      wls_file_persistence_store {a_wls_file_persistence_store :
         ...
         min_window_buffer_size => '-1'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_file_persistence_store:min_window_buffer_size']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC
  include EasyType::Types::Integer
  data_type("Optional[Variant[Enum['absent'],Integer]]")

  maps_to('MinWindowBufferSize')
end
