# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:client_id, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  An optional Client ID for applications that use this JMS connection factory. If the Client ID Policy is set to <code>Restricted </code>(the default), then configuring a Client ID on the connection factory prevents more than one JMS client from using a connection from this factory. This attribute is rarely configured and should normally be left at the default (blank), as JMS application programs can set their Client IDs dynamically using the standard JMS API <code>javax.jms.Connection.setClientID()</code>, and JMS application message processing containers (such as MDBs) normally make the Client ID configurable as part of container configuration. This attribute is dynamic and can be changed at any time. However, changing the value does not affect existing connections. It only affects new connections made with this connection factory.

  An example on how to use this:

      wls_jms_connection_factory {a_wls_jms_connection_factory :
         ...
         client_id => 'a_value'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_jms_connection_factory:client_id']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type('Optional[String]')

  maps_to('ClientParams/%<connection_factory_name>s/ClientId')
end
