# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:client_multicast_overrun_policy, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  The policy to use when the number of outstanding multicast messages reaches the value specified in MessagesMaximum and some messages must be discarded. <ul> <li> Keep New - Indicates that the most recent messages are given priority over the oldest messages, and the oldest messages are discarded, as needed.</li> <li> Keep Old - Indicates that the oldest messages are given priority over the most recent messages, and the most recent messages are discarded, as needed.</li> </ul>  Message age is defined by the order of receipt, not by the <code>JMSTimestamp</code> value. This attribute is dynamic and can be changed at any time. However, changing the value does not affect existing connections. It only affects new connections made with this connection factory.

  An example on how to use this:

      wls_jms_connection_factory {a_wls_jms_connection_factory :
         ...
         client_multicast_overrun_policy => 'KeepOld'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_jms_connection_factory:client_multicast_overrun_policy']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type('Optional[String]')

  maps_to('ClientParams/%<connection_factory_name>s/MulticastOverrunPolicy')
end
