# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:client_subscription_sharing_policy, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  Specifies the subscription sharing policy on this connection. Although this attribute is dynamic, the new values only take effect on future connections and have no impact to existing connections created before the value was changed.  The valid values are: <ul> <li><code>Exclusive</code> - The default. All subscribers created using this connection factory cannot share subscriptions with any other subscribers.</li> <li><code>Sharable</code>  - Subscribers created using this connection factory can share their subscriptions with other subscribers, regardless of whether those subscribers are created using the same connection factory or a different connection factory. Consumers can share a non-durable subscriptions only if they have the same Client ID and Client ID Policy; consumers can share a durable subscription only if they have the same Client ID, Client ID Policy, and Subscription Name. The Sharable Subscription Sharing capability was added in WebLogic 10.3.4 (11gR1PS3).</li> </ul>  Notes: <ul><li>WebLogic JMS applications can override the Subscription Sharing Policy specified on the connection factory configuration by casting a <code>javax.jms.Connection</code> instance to  <code>weblogic.jms.extension.WLConnection</code> and calling <code>setSubscriptionSharingPolicy(String)</code>.</li> <li>Most applications with a Sharable Subscription Sharing Policy will  also use an Unrestricted Client ID Policy in order to ensure that multiple connections with the same client ID can exist.</li> <li>Two durable subscriptions with the same Client ID and Subscription Name are treated as two different independent subscriptions if they have a different Client ID Policy. Similarly, two Sharable non-durable subscriptions with the same Client ID are treated as two different independent subscriptions if they have a different Client ID Policy.</li> <li>Durable subscriptions created using an Unrestricted Client Id must be unsubscribed using <code>weblogic.jms.extensions.WLSession.unsubscribe(Topic topic, String name)</code>, instead of <code>javax.jms.Session.unsubscribe(String name)</code>, regardless of the Subscription Sharing Policy ((Exclusive or Sharable).</li> <li>Sharable subscriptions are not part of the standard JMS 1.1 specification. Although most major JMS vendors support some form of sharable subscriptions, the detailed behavior of shared subscriptions may differ from vendor to vendor.</li> </ul> This attribute is dynamic and can be changed at any time. However, changing the value does not affect existing connections. It only affects new connections made with this connection factory.

  An example on how to use this:

      wls_jms_connection_factory {a_wls_jms_connection_factory :
         ...
         client_subscription_sharing_policy => 'Exclusive'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_jms_connection_factory:client_subscription_sharing_policy']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type('Optional[String]')

  maps_to('ClientParams/%<connection_factory_name>s/SubscriptionSharingPolicy')
end
