# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:client_synchronous_prefetch_mode, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  Specifies whether a synchronous consumer will prefetch messages (that is, messages sent from the server to the client) in one server access.  <ul> <li>Disabled - Indicates that message prefetching is disabled.</li>  <li>Enabled - Indicates that a synchronous consumer (queue receiver or topic subscriber) will prefetch messages. The amount of prefetched messages cannot exceed the maximum number of messages defined by the Messages Maximum parameter.</li>  <li>Topic Subscriber Only - Indicates that only a synchronous topic subscriber will prefetch messages. The amount of prefetched messages cannot exceed the maximum number of messages defined by the Messages Maximum parameter.</li> </ul>  Synchronous message prefetching does not support the following conditions, and will throw a JMS Exception when encountered: <ul> <li>User (XA) transactions for synchronous message receives</li> <li>Multiple synchronous consumers per session (regardless of queue or topic)</li> </ul>  This attribute is dynamic and can be changed at any time. However, changing the value does not affect existing connections. It only affects new connections made with this connection factory.

  An example on how to use this:

      wls_jms_connection_factory {a_wls_jms_connection_factory :
         ...
         client_synchronous_prefetch_mode => 'disabled'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_jms_connection_factory:client_synchronous_prefetch_mode']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type('Optional[String]')

  maps_to('ClientParams/%<connection_factory_name>s/SynchronousPrefetchMode')
end
