# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:errordestination, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  errordestination of the queue.

  DESC

  data_type('Optional[String]')

  maps_to('DeliveryFailureParams/%<queue_name>s/ErrorDestination/')

  on_apply do
    error_type = case resource[:errordestinationtype].to_s
                 when 'Queues'
                   resource[:distributed] == 1 ? 'UniformDistributedQueues' : 'Queues'
                 when 'Topics'
                   resource[:distributed] == 1 ? 'UniformDistributedTopics' : 'Topics'
                 else
                   fail "Internal error. errordestinationtype #{resource[:errordestinationtype]} is unsupported."
                 end
    apply_paths_with_reference("/JMSSystemResources/#{resource[:jmsmodule]}/JMSResource/#{resource[:jmsmodule]}/#{error_type}", value)
  end
end

child_of(:wls_jms_queue, :errordestination) do
  "#{domain}/#{jmsmodule}:#{errordestination}"
end

child_of(:wls_jms_topic, :errordestination) do
  "#{domain}/#{jmsmodule}:#{errordestination}"
end
