# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:attach_sender, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  Specifies whether messages landing on this destination should attach the credential of the sending user. You should consult the JMSXUserID documentation in Programming WebLogic JMS before using this feature.  <ul> <li>Supports The JMSXUserID property is set with the security principal of the sending user if requested. The sender can request its identity to be attached to its messages by using a connection factory with the AttachJMSXUserID security property enabled.</li>  <li>Never The JMSXUserID property is never set with the security principal of the sending user no matter how the AttachJMSXUserID property is configured on connection factories.</li>  <li>Always The JMSXUserID property is always set with the security principal of the sending user no matter how the AttachJMSXUserID property is configured on connection factories.</li> </ul>  This attribute is dynamically configurable. A dynamic change of this attribute will affect only messages received after the update has been made.

  An example on how to use this:

      wls_jms_queue {a_wls_jms_queue :
         ...
         attach_sender => 'supports'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_jms_queue:attach_sender']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type('Optional[String]')

  maps_to('AttachSender')
end
