# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:policy, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  For destinations that use this quota, this policy determines whether to deliver smaller messages before larger ones when a destination has exceeded its message quota.  <code>FIFO</code> (first-in, first-out) indicates that requests for quota are submitted in the order they are received. If a given request for quota cannot be satisfied, and the client requesting the quota is willing to wait, then that request will block all other requests for quota until the request is satisfied or times out. This prevents smaller messages from being delivered when larger requests are already waiting for space.  <code>Preemptive</code> indicates that subsequent requests can preempt previously unsatisfied requests. That is, if there is sufficient quota for the current request, then that space is used even if there are other requests waiting for quota. When quota is limited, the Preemptive policy can result in the starvation of larger requests.

  An example on how to use this:

      wls_jms_quota {a_wls_jms_quota :
         ...
         policy => 'FIFO'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_jms_quota:policy']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type('Optional[String]')

  maps_to('Policy')
end
