# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:sort_order, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  The direction (Ascending or Descending) in which this key will sort messages.   Selecting the Ascending option for the JMSMessageID property implies a FIFO (first in, first out) sort order (the default for destinations). Select the Descending option for a LIFO (last in, first out) sort order.   This attribute is not dynamically configurable.   Gets the "sort-order" element

  An example on how to use this:

      wls_jms_sort_destination_key {a_wls_jms_sort_destination_key :
         ...
         sort_order => 'Ascending'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_jms_sort_destination_key:sort_order']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type('Optional[String]')

  maps_to('SortOrder')
end
