# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:incomplete_work_expiration_time, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  Specifies the maximum amount of time, in milliseconds, before undelivered messages in an incomplete UOW are expired. Such messages will then follow the template's expiration policy defined for undeliverable messages.  Note: A template's error destination for UOW messages cannot be configured to use the Single Message Delivery value.

  An example on how to use this:

      wls_jms_template {a_wls_jms_template :
         ...
         incomplete_work_expiration_time => '-1'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_jms_template:incomplete_work_expiration_time']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC
  include EasyType::Types::Integer
  data_type("Optional[Variant[Enum['absent'],Integer]]")

  maps_to('IncompleteWorkExpirationTime')
end
