# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:delivery_error_destination, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  The name of the target error destination for messages that have expired or reached their redelivery limit. If no error destination is configured, then such messages are simply dropped. If a message has expired or reached its redelivery limit, and the Expiration Policy is set to Redirect, then the message is moved to the specified Error Destination.  For standalone destinations, an error destination must be another standalone destination that is targeted to the same JMS server as the destinations for which the error destination is defined. For uniform distributed destinations (UDDs), the error destination must be another UDD that shares the same subdeployment (i.e., targets) as the current UDD.  This attribute is dynamically configurable, but only incoming messages are impacted; stored messages are not impacted.

  An example on how to use this:

      wls_jms_topic {a_wls_jms_topic :
         ...
         delivery_error_destination => 'a_value'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_jms_topic:delivery_error_destination']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type('Optional[String]')

  maps_to('DeliveryFailureParams/%<topic_name>s/ErrorDestination')
end
