# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:messages_limit_override, :parent => Puppet::Parameter::WlsProperty) do
  include EasyType::Types::Integer

  desc <<-DESC
  The maximum number of messages that can be stored in a topic subscription.  If a new message arrives on subscriptions that have reached the specified limit, then the first-most available messages on these subscriptions will be deleted to make room for the new message. Subscription messages are immune from this deletion if they're participating in a pending transaction, have already been passed to a consumer and are awaiting acknowledgement, or if they are part of a Unit-of-Work that is still waiting to accumulate all of its messages. Note that if all messages are immune from deletion, then a new message can cause a subscription size to exceed its limit.  A value of -1 means no limit override.

  An example on how to use this:

      wls_jms_topic {a_wls_jms_topic :
         ...
         messages_limit_override => -1,
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type("Optional[Variant[Enum['absent'],Integer]]")

  maps_to('TopicSubscriptionParams/%<topic_name>s/MessagesLimitOverride') {}
end
