# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
$LOAD_PATH.unshift File.join(File.dirname(__FILE__), '../..')
require 'puppet_x/enterprisemodules/weblogic/core'

module Puppet
  Type.newtype(:wls_jmsserver) do
    include Puppet_X::EnterpriseModules::WebLogic::Type

    desc <<-DESC
    This resource allows you to manage a jmsserver in an WebLogic domain.

    Here is an example on how you should use this:

        wls_jmsserver { 'jmsServer1':
          ensure                      => 'present',
          persistentstore             => 'jmsFile1',
          persistentstoretype         => 'FileStore',
          target                      => ['wlsServer1'],
          targettype                  => ['Server'],
          allows_persistent_downgrade => '0',
          bytes_maximum               => '-1',
        }

    In this example you are managing a JMS server in the default domain. When you want to
    manage a JMS server in a specific domain, you can use:

        wls_jmsserver { 'my_domain/jmsServer2':
          ensure     => 'present',
          target     => ['wlsServer2'],
          targettype => ['Server'],
        }

    DESC

    bean_type('JMSServer')

    ensurable
    parameter :domain
    parameter :name
    parameter :jmsserver_name
    parameter :timeout
    property :persistentstore
    property :persistentstoretype
    property :target
    property :targettype
    property :bytes_maximum
    property :store_enabled
    property :allows_persistent_downgrade
    extraproperties do
      property :log_buffer_size_kb
      property :log_file_count
      property :log_file_min_size
      property :log_file_name
      property :log_file_rotation_dir
      property :log_notes
      property :log_number_of_files_limited
      property :log_rotation_time
      property :log_rotation_type
      property :bytes_paging_enabled
      property :deployment_order
      property :expiration_scan_interval
      property :hosting_temporary_destinations
      property :insertion_paused_at_startup
      property :log_file_time_span
      property :log_rotate_log_on_startup
      property :maximum_message_size
      property :message_buffer_size
      property :message_compression_options
      property :messages_paging_enabled
      property :messages_threshold_high
      property :notes
      property :paging_block_size
      property :paging_file_locking_enabled
      property :paging_io_buffer_size
      property :paging_max_file_size
      property :paging_max_window_buffer_size
      property :paging_message_compression_enabled
      property :persistent_store
      property :production_paused_at_startup
      property :store_message_compression_enabled
      property :blocking_send_policy
      property :bytes_threshold_high
      property :bytes_threshold_low
      property :consumption_paused_at_startup
      property :messages_maximum
      property :messages_threshold_low
      property :paging_directory
      property :paging_min_window_buffer_size
      property :temporary_template_name
      property :temporary_template_resource
      #
      # Weblogic 12.2.1 new properties
      #
      property :log_date_format_pattern
      property :log_tags
      property :tags
    end

    add_title_attributes(:jmsserver_name)
  end
end
