# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:adapter_version, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  Gets the node manager client adapter version when using a VMM adapter to connect to OVM or other VMM adapters providers

  An example on how to use this:

      wls_machine {a_wls_machine :
         ...
         adapter_version => 'a_value'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_machine:adapter_version']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type('Optional[String]')

  maps_to('NodeManager/%<machine_name>s/AdapterVersion')
end
