# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:batch_size, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  The number of messages that are processed within one transaction.  <code>Batch Size</code> only applies to a messaging bridge instance forwarding messages in synchronous mode and has a QOS (quality of service) that requires two-phase transactions.

  An example on how to use this:

      wls_messaging_bridge {a_wls_messaging_bridge :
         ...
         batch_size => '10'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_messaging_bridge:batch_size']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC
  include EasyType::Types::Integer
  data_type("Optional[Variant[Enum['absent'],Integer]]")

  maps_to('BatchSize')
end
