# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:reconnect_delay_increase, :parent => Puppet::Parameter::WlsProperty) do
  include EasyType::Types::Integer

  desc <<-DESC
  The incremental delay time, in seconds, that a messaging bridge instance increases its waiting time between one failed reconnection attempt and the next retry.  <ul> <li> Use with <tt>ReconnectDelayMinimum</tt> and <tt>ReconnectDelayMaximum</tt>. After the first failure to connect to a destination, the bridge instance waits for the number of seconds defined by <tt>ReconnectDelayMinimum</tt>. Each time a reconnect attempt fails, the bridge instance increases its waiting time by the number of seconds defined by <tt>ReconnectDelayIncrease</tt>. The maximum delay time is defined by <tt>ReconnectDelayMaximum</tt>. Once the waiting time is increased to the maximum value, the bridge instance stops increase its waiting time. Once the bridge instance successfully connects to the destination, the bridge instance resets its waiting time to the initial value defined by <tt>ReconnectDelayMinimum</tt>. </li>

  An example on how to use this:

      wls_messaging_bridge {a_wls_messaging_bridge :
         ...
         reconnect_delay_increase => '5'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_messaging_bridge:reconnect_delay_increase']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type("Optional[Variant[Enum['absent'],Integer]]")

  maps_to('ReconnectDelayIncrease')
end
