# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
$LOAD_PATH.unshift File.join(File.dirname(__FILE__), '../..')
require 'puppet_x/enterprisemodules/weblogic/core'

module Puppet
  Type.newtype(:wls_migratable_target) do
    include Puppet_X::EnterpriseModules::WebLogic::Type

    desc <<-DESC
    This resource allows you to managed migratable targets in a WebLogic domain.

    Here is an example on how you should use this:

        wls_migratable_target { 'wlsServer1 (migratable)':
          ensure                     => 'present',
          cluster                    => 'WebCluster',
          migration_policy           => 'manual',
          number_of_restart_attempts => '6',
          seconds_between_restarts   => '30',
          user_preferred_server      => 'wlsServer1',
        }

    In this example you are managing a migratable target in the default domain. When you want to
    manage a migratable target in a specific domain, you can use:

        wls_migratable_target { 'my_domain/wlsServer2 (migratable)':
          ensure                     => 'present',
          cluster                    => 'WebCluster',
          migration_policy           => 'manual',
          number_of_restart_attempts => '6',
          seconds_between_restarts   => '30',
          user_preferred_server      => 'wlsServer2',
        }

    Here are some more examples:

        wls_migratable_target { 'Wls11gSetting/wlsServer1 (migratable)':
          ensure                     => 'present',
          cluster                    => 'WebCluster',
          migration_policy           => 'manual',
          number_of_restart_attempts => '6',
          seconds_between_restarts   => '30',
          user_preferred_server      => 'wlsServer1',
        }
        wls_migratable_target { 'Wls11gSetting/wlsServer2 (migratable)':
          ensure                     => 'present',
          cluster                    => 'WebCluster',
          migration_policy           => 'manual',
          number_of_restart_attempts => '6',
          seconds_between_restarts   => '30',
          user_preferred_server      => 'wlsServer2',
        }

    DESC

    bean_type('MigratableTarget')

    ensurable
    parameter :migratable_target_name
    parameter :domain
    parameter :name

    property :cluster
    property :number_of_restart_attempts
    property :seconds_between_restarts
    property :constrained_candidate_servers
    property :user_preferred_server
    property :migration_policy
    extraproperties do
      property :additional_migration_attempts
      property :millis_to_sleep_between_attempts
      property :non_local_post_allowed
      property :post_script_failure_fatal
      property :post_script
      property :pre_script
      property :restart_on_failure
      #
      # Weblogic 12.2.1 new properties
      #
      property :critical
      property :hosting_server
      property :notes
      property :tags
    end

    add_title_attributes(:migratable_target_name)
  end
end
