# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:non_local_post_allowed, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  Specifies whether or not the post-deactivation script is allowed to run on a different machine.  Normally, when auto migration occurs, the post-deactivation script will be run on the service's current location, and the pre-activation script on the service's new location. If the current location is unreachable for some reason, this value will be checked to see if it is safe to run it on the service's new machine.  This is useful if the post-deactivation script controls access to a networked resource and does not need any data from the current machine.

  An example on how to use this:

      wls_migratable_target {a_wls_migratable_target :
         ...
         non_local_post_allowed => 1,
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_migratable_target:non_local_post_allowed']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type("Optional[Variant[Enum['absent'],Integer[0,1]]]")

  include Puppet_X::EnterpriseModules::WebLogic::Types::NumberedBoolean

  maps_to('NonLocalPostAllowed')
end
