# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:ds_scope, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  Specifies the scoping of the data source.  You can specify one of the following scopes:  <ul> <li>Global  Specifies that the data source is bound in the cluster-wide JNDI tree with the JNDIName specified so that the data source is available for use to any JDBC client across the cluster.  This is the default setting. </li>  <li>Application  Specifies that the data source is bound in the application's local namespace with the JNDIName specified so that the data source is available for use only by JDBC clients within the application.  This can only be used for packaged datasources and is ignored for JDBC System resources. </li> </ul>

  An example on how to use this:

      wls_multi_datasource {a_wls_multi_datasource :
         ...
         ds_scope => 'Global'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_multi_datasource:ds_scope']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type('Optional[String]')

  maps_to('JDBCResource/%<multi_datasource_name>s/JDBCDataSourceParams/%<multi_datasource_name>s/Scope')
end
