# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:oracle_connection_initialization_callback, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  The name of the Connection Initialization Callback class.  This name is automatically passed to <code>registerConnectionInitializationCallback</code> when a data source is created. The class must implement <code>oracle.ucp.jdbc.ConnectionInitializationCallback</code>.

  An example on how to use this:

      wls_multi_datasource {a_wls_multi_datasource :
         ...
         oracle_connection_initialization_callback => 'a_value'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_multi_datasource:oracle_connection_initialization_callback']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type('Optional[String]')

  maps_to('JDBCResource/%<multi_datasource_name>s/JDBCOracleParams/%<multi_datasource_name>s/ConnectionInitializationCallback')
end
