# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:oracle_ons_wallet_password, :parent => Puppet::Parameter::WlsEncryptedProperty) do
  desc <<-DESC
  The wallet password attribute that is included as part of the ONS client configuration string. This attribute is only required when ONS is configured to use the SSL protocol.  The value is stored in an encrypted form in the descriptor file and when displayed in an administration console.

  An example on how to use this:

      wls_multi_datasource {a_wls_multi_datasource :
         ...
         oracle_ons_wallet_password => 'a_value'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_multi_datasource:oracle_ons_wallet_password']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type('Optional[String]')

  maps_to('JDBCResource/%<multi_datasource_name>s/JDBCOracleParams/%<multi_datasource_name>s/OnsWalletPassword')
end
