# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:pool_wrap_jdbc, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  By default, SQL objects for <code>CallableStatement</code>, <code>PreparedStatement</code>, <code>ResultSet</code>, <code>Statement</code>, and <code>DatabaseMetaData</code> are wrapped with a WebLogic wrapper. Wrapping allows features like debugging and connection usage to be performed by the server.  When <code>false</code>, wrapping is disabled. This improves performance, in some cases significantly, and allows for the application to use the native driver objects directly. A value of <code>false</code> also disables data type wrapping.

  An example on how to use this:

      wls_multi_datasource {a_wls_multi_datasource :
         ...
         pool_wrap_jdbc => 1,
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_multi_datasource:pool_wrap_jdbc']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  include Puppet_X::EnterpriseModules::WebLogic::Types::NumberedBoolean
  data_type("Optional[Variant[Enum['absent'],Integer[0,1]]]")

  maps_to('JDBCResource/%<multi_datasource_name>s/JDBCConnectionPoolParams/%<multi_datasource_name>s/WrapJdbc')
end
