# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:default_retry_delay_multiplier, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  The factor used to multiply the previous delay time to calculate the next delay time to be used.  <ul> <li> Applies only to agents with sending capability. </li>  <li> Updating <code>DefaultRetryDelayMuliplier</code> causes connections starting after the update to use the new value. </li> </ul>  Range of Values: &gt;= 1.

  An example on how to use this:

      wls_safagent {a_wls_safagent :
         ...
         default_retry_delay_multiplier => '1.0'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_safagent:default_retry_delay_multiplier']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type('Optional[Float]')

  maps_to('DefaultRetryDelayMultiplier')
end
