# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:logging_enabled, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  Specifies whether a message is logged in the server log file when a message fails to be forwarded.  <ul> <li> If selected, this applies to messages that fail to be forwarded and delivered to the final destination when there is no error handling in a SAF application or the application's error handling fails. </li>  <li> Applies only to agents with receiving capability. </li>  <li> Updating <code>LoggingEnabled</code> causes connections starting after the update to use the new value. </li> </ul>

  An example on how to use this:

      wls_safagent {a_wls_safagent :
         ...
         logging_enabled => 1,
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_safagent:logging_enabled']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  include Puppet_X::EnterpriseModules::WebLogic::Types::NumberedBoolean
  data_type("Optional[Variant[Enum['absent'],Integer[0,1]]]")

  maps_to('LoggingEnabled')
end
