# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:paging_directory, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
   Specifies where message bodies are written when the size of the message bodies in the JMS server exceeds the message buffer size. If unspecified, messages are written to the <code>tmp</code> directory in the host WebLogic Server instance's directory. For example, <code><em>domainName</em>/servers/<em>servername</em>/tmp</code>.   <ul> <li> For best performance, this directory should not be the same as the directory used by the SAF agent's persistent store. </li>  <li> Applies only to agents with sending capability. </li> </ul>

  An example on how to use this:

      wls_safagent {a_wls_safagent :
         ...
         paging_directory => 'a_value'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_safagent:paging_directory']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  maps_to('PagingDirectory')
end
