# frozen_string_literal: true

newproperty(:credential_mapper_types, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  Returns the types of Credential Mapping providers that may be created in this security realm, for example, <code>weblogic.security.providers.credentials.DefaultCredentialMapper</code>. Use this method to find the available types to pass to <code>createCredentialMapper</code>

  An example on how to use this:

      wls_security_realm {a_wls_security_realm :
         ...
         credential_mapper_types => 'a_value'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_security_realm:credential_mapper_types']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  maps_to('CredentialMapperTypes')
end
