# frozen_string_literal: true

newproperty(:enable_web_logic_principal_validator_cache, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  Returns whether the WebLogic Principal Validator caching is enabled.  The Principal Validator is used by Oracle supplied authentication providers and may be used by custom authentication providers. If enabled, the default principal validator will cache WebLogic Principal signatures.

  An example on how to use this:

      wls_security_realm {a_wls_security_realm :
         ...
         enable_web_logic_principal_validator_cache => '1'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_security_realm:enable_web_logic_principal_validator_cache']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type("Optional[Variant[Enum['absent'],Integer[0,1]]]")

  include Puppet_X::EnterpriseModules::WebLogic::Types::NumberedBoolean

  maps_to('EnableWebLogicPrincipalValidatorCache')
end
