# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:complete_http_message_timeout, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  The maximum number of seconds spent waiting for a complete HTTP message to be received. If you configure network channels for this server, each channel can override this HTTP message timeout.  This timeout helps guard against a denial of service attack in which a caller indicates that it will be sending a message of a certain size which it never finishes sending.  A value of -1 indicates that this value should be obtained from network channels configured for this server.

  An example on how to use this:

      wls_server {a_wls_server :
         ...
         complete_http_message_timeout => '-1'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_server:complete_http_message_timeout']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  maps_to('CompleteHTTPMessageTimeout')
end
