# frozen_string_literal: true

newproperty(:migration_critical, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  Returns true if the MigratableTarget is critical to the overall health of the WLS Server

  An example on how to use this:

      wls_server {a_wls_server :
         ...
         migration_critical => '1'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_server:migration_critical']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  include Puppet_X::EnterpriseModules::WebLogic::Types::NumberedBoolean
  data_type("Optional[Variant[Enum['absent'],Integer[0,1]]]")

  maps_to('JTAMigratableTarget/%<server_name>s/Critical') {}
end
