# frozen_string_literal: true

newproperty(:migration_seconds_between_restarts, :parent => Puppet::Parameter::WlsProperty) do
  include EasyType::Validators::Integer

  desc <<-DESC
  Specifies how many seconds to wait in between attempts to restart the failed service.

  An example on how to use this:

      wls_server {a_wls_server :
         ...
         migration_seconds_between_restarts => '30'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_server:migration_seconds_between_restarts']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type("Optional[Variant[Enum['absent'],Integer]]")

  maps_to('JTAMigratableTarget/%<server_name>s/SecondsBetweenRestarts') {}
end
