# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:print_stack_trace_in_production, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  Specifies whether the server message log includes exception stack trace that are raised in remote systems.

  An example on how to use this:

      wls_server {a_wls_server :
         ...
         print_stack_trace_in_production => 1,
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_server:print_stack_trace_in_production']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  include Puppet_X::EnterpriseModules::WebLogic::Types::NumberedBoolean
  data_type("Optional[Variant[Enum['absent'],Integer[0,1]]]")

  maps_to('PrintStackTraceInProduction')
end
