# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:socket_buffer_size_as_chunk_size, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  Specifies whether the server's buffer size for sending or receiving data through a raw socket should be set to 4KB.  Otherwise, the server does not impose a limit to the buffer size and defers to the operating system. This option is useful only on some operating systems for improving performance. It should be disabled in most environments.

  An example on how to use this:

      wls_server {a_wls_server :
         ...
         socket_buffer_size_as_chunk_size => 1,
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_server:socket_buffer_size_as_chunk_size']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  include Puppet_X::EnterpriseModules::WebLogic::Types::NumberedBoolean
  data_type("Optional[Variant[Enum['absent'],Integer[0,1]]]")

  maps_to('SocketBufferSizeAsChunkSize')
end
