# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:staging_directory_name, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  The directory path on the Managed Server where all staged (prepared) applications are placed.  If an absolute directory name is not specified, the path is relative to the root directory "/". Once configured, you cannot change the staging directory name. Remove all applications from the server prior to changing this attribute. The default staging directory is "stage", relative to the server root.

  An example on how to use this:

      wls_server {a_wls_server :
         ...
         staging_directory_name => 'a_value'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_server:staging_directory_name']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  maps_to('StagingDirectoryName')
end
