# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:webserver_max_post_size, :parent => Puppet::Parameter::WlsProperty) do
  include EasyType::Validators::Integer

  desc <<-DESC
  The maximum post size this server allows for reading HTTP POST data in a servlet request.  A value less than 0 indicates an unlimited size.  Gets the maxPostSize attribute of the WebServerMBean object

  An example on how to use this:

      wls_server {a_wls_server :
         ...
         webserver_max_post_size => '-1'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_server:webserver_max_post_size']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  maps_to('WebServer/%<server_name>s/MaxPostSize')
end
