# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:ciphersuites, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  Indicates the cipher suites being used on a particular WebLogic Server channel.  The strongest negotiated cipher suite is chosen during the SSL handshake. The set of cipher suites used by default by JSEE depends on the specific JDK version with which WebLogic Server is configured.  For a list of possible values, see <a href="http://www.oracle.com/pls/topic/lookup?ctx=fmw121300&id=SECMG502">Cipher Suites.</a>

  An example on how to use this:

      wls_server_channel {a_wls_server_channel :
         ...
         ciphersuites => 'a_value'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_server_channel:ciphersuites']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  maps_to('Ciphersuites')
end
