# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:cluster_address, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  The address this network channel uses to generate EJB handles and failover addresses for use in a cluster. This value is determined according to the following order of precedence:

  - If the cluster address is specified via the NAPMBean, then that value is used
  - If this value is not specified, the value of PublicAddress is used.
  - If PublicAddress is not set, this value is derive from the ClusterAddress attribute of the ClusterMbean.
  - If ClusterMbean.clusterAddress is not set, this value is derive from the listen address of the NAPMbean.

  An example on how to use this:

      wls_server_channel {a_wls_server_channel :
         ...
         cluster_address => 'a_value'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_server_channel:cluster_address']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  maps_to('ClusterAddress')
end
