# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:complete_message_timeout, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  The maximum amount of time this network channel waits for a complete message to be received. A value of <code>0</code> disables network channel complete message timeout. A value of <tt>-1</tt> indicates that the network channel obtains this timeout value from the ServerTemplateMBean.  This timeout helps guard against denial of service attacks in which a caller indicates that they will be sending a message of a certain size which they never finish sending.

  An example on how to use this:

      wls_server_channel {a_wls_server_channel :
         ...
         complete_message_timeout => 'a_value'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_server_channel:complete_message_timeout']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  maps_to('CompleteMessageTimeout')
end
