# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:private_key_alias, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  The string alias used to store and retrieve the channel's private key in the keystore. This private key is associated with the server's digital certificate. This value is derived from other settings on the channel and cannot be physically set.

  An example on how to use this:

      wls_server_channel {a_wls_server_channel :
         ...
         private_key_alias => 'a_value'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_server_channel:private_key_alias']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  maps_to('PrivateKeyAlias')
end
