# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:auto_migration_enabled, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  Specifies whether Node Manager can automatically restart this server and its services on another machine if the server fails.

  An example on how to use this:

      wls_server_template {a_wls_server_template :
         ...
         auto_migration_enabled => 1,
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_server_template:auto_migration_enabled']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  include Puppet_X::EnterpriseModules::WebLogic::Types::NumberedBoolean
  data_type("Optional[Variant[Enum['absent'],Integer[0,1]]]")

  maps_to('AutoMigrationEnabled')
end
