# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:custom_trust_key_store_file_name, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  The source of the custom trust keystore. For a JKS keystore, the source is the path and file name. For an Oracle Key Store Service (KSS) keystore, the source is the KSS URI.  If using a JKS keystore, the keystore path name must either be absolute or relative to where the server was booted.  If using a KSS keystore, the keystore URI must be of the form:<br/> &quot;<code>kss://system/keystorename</code>&quot;<br/> where &quot;<code>keystorename</code>&quot; is the name of the keystore registered in KSS.   The value in this attribute is only used if KeyStores is  CUSTOM_IDENTITY_AND_CUSTOM_TRUST.

  An example on how to use this:

      wls_server_template {a_wls_server_template :
         ...
         custom_trust_key_store_file_name => 'a_value'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_server_template:custom_trust_key_store_file_name']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  maps_to('CustomTrustKeyStoreFileName')
end
