# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:transaction_log_file_write_policy, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  The policy that determines how transaction log file entries are written to disk. This policy can affect transaction performance. (Note: To be transactionally safe, the Direct-Write policy may require additional OS or environment changes on some Windows systems.)  WebLogic Server supports the following policies:  <ul> <li> Cache-Flush. Flushes operating system and on-disk caches after each write. </li>  <li> Direct-Write. Tells the operating system to write directly to disk with each write. Direct-Write performs better than Cache-Flush. </li> </ul>  If Direct-Write is not supported on the host platform, the policy becomes Cache-Flush and a log message is printed.  Note: On Windows, the "Direct-Write" policy may leave transaction data in the on-disk cache without writing it to disk immediately. This is not transactionally safe because a power failure can cause loss of on-disk cache data. For transactionally safe writes using "Direct-Write" on Windows, either disable all write caching for the disk (enabled by default), or use a disk with a battery-backed cache.  The on-disk cache for a hard-drive on Windows can be disabled through system administration: Control-Panel -&gt; System -&gt; Hardware-tab -&gt; Device-Manager-button -&gt; Disk-Drives -&gt; name-of-drive -&gt; Policies-tab -&gt; "Enable write caching on the disk" check-box. Some file systems do not allow this value to be changed. For example, a RAID system that has a reliable cache.

  An example on how to use this:

      wls_server_template {a_wls_server_template :
         ...
         transaction_log_file_write_policy => 'Direct-Write'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_server_template:transaction_log_file_write_policy']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  maps_to('TransactionLogFileWritePolicy')
end
