# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:max_retry_seconds_before_tx_exception, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  The maximum amount of time, in seconds, WebLogic Server waits before trying to recover from a JDBC TLog store failure while processing a transaction. If store remains unusable after this amount of time, WebLogic Server throws an exception the affected transaction. A value of 0 indicates WebLogic Server does not conduct a retry and an exception will thrown immediately. The practical maximum value is a value less than the current value of <code>MaxRetrySecondsBeforeTLogFail</code>.

  An example on how to use this:

      wls_server_tlog {a_wls_server_tlog :
         ...
         max_retry_seconds_before_tx_exception => '60'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_server_tlog:max_retry_seconds_before_tx_exception']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  maps_to('MaxRetrySecondsBeforeTXException')
end
