# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:prefix_name, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  When using multiple TLOG JDBC stores, use this attribute to create a label ending in "_"  that is prepended to the name of the server hosting the JDBC TLOG store and ends in "_" to form a unique JDBC TLOG store name for each configured JDBC TLOG store.  The default prefix name is "TLOG_" . For example, a valid JDBC TLOG store name using the default Prefix Name is <code>TLOG_MyServer_ </code> where TLOG_ is the Prefix Name and MyServer is the name of the server hosting the JDBC TLOG store.

  An example on how to use this:

      wls_server_tlog {a_wls_server_tlog :
         ...
         prefix_name => 'a_value'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_server_tlog:prefix_name']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  maps_to('PrefixName')
end
