# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:reconnect_retry_interval_millis, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  The length of time in milliseconds between reconnection attempts during the reconnection retry period.  The reconnection interval applies to JDBC connections regardless of the database that is used for the JDBC store.  The default value is 200 milliseconds

  An example on how to use this:

      wls_server_tlog {a_wls_server_tlog :
         ...
         reconnect_retry_interval_millis => '200'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_server_tlog:reconnect_retry_interval_millis']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  maps_to('ReconnectRetryIntervalMillis')
end
