# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:log_rotation_time, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  Determines the start time (hour and minute) for a time-based rotation sequence.  At the time that this value specifies, the server renames the current log file. Thereafter, the server renames the log file at an interval that you specify in File Time Span.  Note that WebLogic Server sets a threshold size limit of 500 MB before it forces a hard rotation to prevent excessive log file growth.   Use the following format: <code>H:mm</code>, where <ul><li><code>H</code> is Hour in day (0-23). <li><code>mm</code> is the minute in hour </ul>#{'  '}

  An example on how to use this:

      wls_virtual_host {a_wls_virtual_host :
         ...
         log_rotation_time => '00:00'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_virtual_host:log_rotation_time']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  maps_to('WebServerLog/%<virtual_host_name>s/RotationTime')
end
