# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
$LOAD_PATH.unshift File.join(File.dirname(__FILE__), '../..')
require 'puppet_x/enterprisemodules/weblogic/core'

module Puppet
  Type.newtype(:wls_virtual_target) do
    include Puppet_X::EnterpriseModules::WebLogic::Type

    desc 'This resource allows you to manage virtual targets in an WebLogic 12.2.1 domain.'

    bean_type('VirtualTarget')

    ensurable
    parameter :domain
    parameter :name
    parameter :virtual_target_name
    parameter :timeout
    property :channel
    property :target
    property :targettype
    property :virtual_host_names
    property :port
    property :portoffset
    property :uriprefix
    extraproperties do
      property :log_tags
      property :http_accept_context_path_in_get_real_path
      property :http_auth_cookie_enabled
      property :http_charsets
      property :http_chunked_transfer_disabled
      property :http_deployment_order
      property :http_https_keep_alive_secs
      property :http_keep_alive_enabled
      property :http_keep_alive_secs
      property :http_max_post_time_secs
      property :log_buffer_size_kb
      property :log_date_format_pattern
      property :log_elf_fields
      property :log_file_count
      property :log_file_format
      property :log_file_min_size
      property :log_file_name
      property :log_file_rotation_dir
      property :log_file_time_span
      property :log_logging_enabled
      property :log_notes
      property :log_number_of_files_limited
      property :log_rotate_log_on_startup
      property :log_rotation_time
      property :log_rotation_type
      property :log_time_in_gmt
      property :http_client_ip_header
      property :http_default_web_app_context_root
      property :http_frontend_host
      property :http_max_request_parameter_count
      property :http_notes
      property :http_post_timeout_secs
      property :http_single_signon_disabled
      property :http_tags
      property :http_url_resource
      property :http_use_highest_compatible_http_version
      property :http_wap_enabled
      property :deployment_order
      property :explicit_port
      property :http_frontend_http_port
      property :http_frontend_https_port
      property :http_max_post_size
      property :http_overload_response_code
      property :http_send_server_header_enabled
      property :http_use_header_encoding
      property :http_write_chunk_bytes
      property :notes
      property :tags
      property :host_names
      property :partition_channel
      property :port_offset
      property :uri_prefix
    end

    add_title_attributes(:virtual_target_name)
  end
end
