# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:http_send_server_header_enabled, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  Indicates whether this server name is sent with the HTTP response. (This is useful for wireless applications where there is limited space for headers.)  Indicates whether this server instance includes its name and WebLogic Server version number in HTTP response headers.

  An example on how to use this:

      wls_virtual_target {a_wls_virtual_target :
         ...
         http_send_server_header_enabled => 1,
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_virtual_target:http_send_server_header_enabled']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  include Puppet_X::EnterpriseModules::WebLogic::Types::NumberedBoolean
  data_type("Optional[Variant[Enum['absent'],Integer[0,1]]]")

  maps_to('WebServer/%<virtual_target_name>s/SendServerHeaderEnabled')
end
